PostgresqlDataAttribute class

Inheritance

Constructors

PostgresqlDataAttribute({required DataField field, required String name, required PostgresqlDataType type, List<PostgresqlAttributeConstraint> constraints = const []})
PostgresqlDataAttribute.fromField(DataField field)
factory

Properties

constraints List<PostgresqlAttributeConstraint>
finalinherited
field → DataField
final
hashCode int
The hash code for this object.
no setterinherited
name String
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type PostgresqlDataType
finalinherited

Methods

hasConstraint<T extends PostgresqlAttributeConstraint>([bool test(T)?]) bool
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited