PostgresqlDataType<T> class abstract

Implementers

Constructors

PostgresqlDataType(String name, Type<Object> pgType)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
final
pgType → Type<Object>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type → TypeCheck<T>
no setter

Methods

decode(dynamic value) → T?
encode(T? value) → dynamic
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sqlLiteral(T? value) Sql
sqlParam(T? value) Sql
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

findForDataField(DataField field) PostgresqlDataType
findForDynamic(dynamic v) PostgresqlDataType