PostgresqlFunctionExpression class

Constructors

PostgresqlFunctionExpression(String name, List<Expression> arguments, [PostgresqlDataType? returnType])
const

Properties

arguments List<Expression>
final
hashCode int
The hash code for this object.
no setterinherited
name String
final
returnType PostgresqlDataType?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited